import unittest
from modela import *


class Test_Modela_study(unittest.TestCase):
    """Tests for `modela.training.Study`"""
    resource: Study = None

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def request_resource(self, name, **kwargs) -> Study:
        self.clear_resource()
        try:
            self.modela.Datasets.get("iris-product", "test-ds-gen")
        except ResourceNotFoundException:
            self.modela.Dataset(namespace="iris-product",
                                name="test-ds-gen",
                                data_file='datasets/iris.csv',
                                bucket="default-minio-bucket",
                                gen_datasource=True,
                                task_type=TaskType.MultiClassification,
                                target_column="variety").submit_and_visualize(replace=True)

        Test_Modela_study.resource = self.modela.Study(namespace="iris-product",
                                                       name=name,
                                                       dataset="test-ds-gen",
                                                       objective=Metric.Accuracy,
                                                       **kwargs)
        return Test_Modela_study.resource

    def clear_resource(self):
        if Test_Modela_study.resource:
            Test_Modela_study.resource.delete()
            Test_Modela_study.resource = None

    def test_0_create_actions(self):
        loop = asyncio.new_event_loop()
        study = self.request_resource("test-study")
        study.submit(replace=True)
        loop.run_until_complete(study.wait_until_phase(StudyPhase.EngineeringFeature))
        study.pause()
        time.sleep(1)
        assert study.status.Phase == StudyPhase.Paused
        study.resume()
        loop.run_until_complete(study.wait_until_phase(StudyPhase.EngineeringFeature))
        study.abort()
        time.sleep(1)
        assert study.status.Phase == StudyPhase.Aborted
        self.clear_resource()


    def test_1_viz(self):
        study = self.request_resource("test-study",
                                      search=ModelSearch(MaxTime=200, MaxModels=3, Trainers=2,
                                                         SearchSpace=AlgorithmSearchSpace(
                                                             Allowlist=[
                                                                 ClassicEstimator.LogisticRegression])),
                                      garbage_collect=False)
        study.submit_and_visualize(replace=True)

    def test_2_list(self):
        assert len(self.modela.Studies.list("iris-product")) >= 1
        assert len(Test_Modela_study.resource.models) > 0

    def test_3_update(self):
        Test_Modela_study.resource.set_label("test", "e")
        Test_Modela_study.resource.update()
        newStudy = self.modela.Study(namespace="iris-product", name="test-study")
        assert newStudy.has_label("test")

    def test_3_get(self):
        assert Test_Modela_study.resource.phase == StudyPhase.Completed
        assert Test_Modela_study.resource.best_model.spec.Estimator.AlgorithmName == "logistic-regression"



""" These tests should be run by an end-user on a functional terminal """
def test_viz():
    modela = Modela(port_forward=True)
    study = modela.Study(
        name="test-study-2",
        namespace="iris-product",
        dataset="iris",
        task_type=TaskType.MultiClassification,
        objective=Metric.Accuracy,
        bucket="default-minio-bucket",
        search=ModelSearch(MaxTime=200, MaxModels=8, Trainers=4))

    study.submit_and_visualize(replace=True)
    modela.close()



import unittest

from modela.ModelaException import *
from modela.inference.Predictor import Predictor
from modela.inference.models import PredictorSpec
from modela.server import Modela
from modela import *


class Test_Modela_predictor(unittest.TestCase):
    """Tests for `modela.inference.Predictor`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)
        return
        models = [model for model in cls.modela.Models.list("iris-product") if
                  model.phase in (ModelPhase.Completed, ModelPhase.Live)]
        if len(models) != 0:
            cls.model = models[0]
        else:
            cls.modela.Dataset(namespace="iris-product",
                               name="test-pred-gen-5",
                               data_file='datasets/iris.csv',
                               bucket="default-minio-bucket",
                               gen_datasource=True,
                               target_column="variety",
                               task_type=TaskType.MultiClassification,
                               fast=True).submit_and_visualize(replace=True)
            study = cls.modela.Study(namespace="iris-product",
                                     name="test-pred-gen-5",
                                     dataset="test-pred-gen-5", objective=Metric.Accuracy,
                                     search=ModelSearch(MaxTime=200, MaxModels=1, Trainers=1),
                                     fe_search=FeatureEngineeringSearch(Enabled=False),
                                     fast=True)
            study.submit_and_visualize(replace=True)
            cls.model = study.best_model

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_0_create(self):
        predictor = self.modela.Predictor(namespace="iris-product", name="p-model-20220511-153544")#"test-pred", model=Test_Modela_predictor.model)
        predictor.submit(replace=True)

    def test_1_list(self):
        assert len(self.modela.Predictors.list("iris-product")) >= 1

    def test_2_update(self):
        predictor = self.modela.Predictor(namespace="iris-product", name="test-pred")
        predictor.set_label("test", "e")
        predictor.update()
        newds = self.modela.Predictor(namespace="iris-product", name="test-pred")
        assert newds.has_label("test")

    def test_3_predict(self):
        predictor = self.modela.Predictor(namespace="iris-product", name="test-pred")
        predictor.submit(replace=True)
        loop = asyncio.new_event_loop()
        loop.run_until_complete(predictor.wait_until_ready())
        print(predictor.predict(predictor.model.test_prediction))


    def test_4_delete(self):
        predictor = self.modela.Predictor(namespace="iris-product", name="test-pred")
        predictor.delete()
        self.assertRaises(ResourceNotFoundException, self.modela.Studies.get, "iris-product", "test")



import unittest

from modela.ModelaException import *
from modela.inference.InferenceService import InferenceService
from modela.training.Model import Model
from modela.server import Modela
from modela.training.models import ModelSpec
import pprint
from modela import *

class Test_Modela_model(unittest.TestCase):
    """Tests for `modela.training.Model`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_connect_predictor(self):
        predictor = self.modela.Predictor("iris-product", "test-ingress")
        #serve = predictor.connect()
        serve = InferenceService("serving.vcap.me", secure=True, tls_cert='tests/inference_server.crt')
        predictions = serve.predict("iris-product", "model-20220219-002120",
                                             "[{\"sepal.length\":4.6, \"sepal.width\":3.2, \"petal.length\":1.0, \"petal.width\":0.3}]",
                                    explain=True)
        print(predictions)
        assert predictions[0].Label == "Setosa"



import unittest

from modela.ModelaException import *
from modela.training.Model import Model
from modela.server import Modela
from modela.training.models import ModelSpec
import pprint

class Test_Modela_model(unittest.TestCase):
    """Tests for `modela.training.Model`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_0_list(self):
        assert len(self.modela.Models.list("iris-product")) >= 1

    def test_0_print_details(self):
        model = self.modela.Models.list("iris-product")[-1]
        print(model.details)


    def test_1_get(self):
        model = self.modela.Models.list("iris-product")[0]
        spec = model.spec
        print(model)
        assert type(spec) == ModelSpec



import unittest

from modela.ModelaException import *
from modela.training.Report import Report
from modela.server import Modela
from modela import *

class Test_Modela_report(unittest.TestCase):
    """Tests for `modela.training.Report`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_1_list(self):
        assert len(self.modela.Reports.list("iris-product")) >= 1

    def test_2_get(self):
        report = self.modela.Report(namespace="iris-product", name="test")
        spec = report.spec
        assert type(spec) == ReportSpec

    def test_3_download(self):
        report = self.modela.Reports.list("iris-product")[0]
        assert len(report.download()) > 1000




import unittest

from modela import *
import pprint


class Test_Modela_userroleclass(unittest.TestCase):
    """Tests for `modela.training.UserRoleClass`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_list(self):
        assert len(self.modela.UserRoleClasses.list("default-tenant")) >= 1

    def test_get(self):
        role = self.modela.UserRoleClass("default-tenant", "administrator")
        assert len(role.rules) > 0
        assert Verb.All in role.rule(ResourceKind.Study).Verbs

    def test_write(self):
        role = self.modela.UserRoleClass("default-tenant", "business")
        role.allow_verb(ResourceKind.Job, Verb.Watch)
        assert Verb.Watch in role.rule(ResourceKind.Job).Verbs
        role.allow_all(ResourceKind.Job)
        assert Verb.All in role.rule(ResourceKind.Job).Verbs
        role.deny_verb(ResourceKind.Job, Verb.Delete)
        assert set(role.rule(ResourceKind.Job).Verbs) == {Verb.Patch, Verb.Watch, Verb.Update, Verb.Create, Verb.List, Verb.Get}
        role.deny_all(ResourceKind.Job)
        assert len(role.rule(ResourceKind.Job).Verbs) == 0


import unittest
from modela import *

class Test_Modela_modelautobuilder(unittest.TestCase):
    """Tests for `modela.training.ModelAutobuilder`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_create(self):
        resource = self.modela.ModelAutobuilder(namespace="iris-product", name="test-mab",
                                                data_file="datasets/iris.csv",
                                                target_column="variety",
                                                task_type=TaskType.MultiClassification)
        resource.submit(replace=True)
        loop = asyncio.new_event_loop()
        loop.run_until_complete(resource.wait_until_phase(ModelAutobuilderPhase.DatasetCompleted))
        assert resource.datasource.reference == ObjectReference("iris-product", "test-mab")
        assert resource.dataset.reference == ObjectReference("iris-product", "test-mab")
        loop.run_until_complete(resource.wait_until_phase(ModelAutobuilderPhase.StudyCompleted))
        assert resource.study.reference == ObjectReference("iris-product", "test-mab")
        loop.run_until_complete(resource.wait_until_phase(ModelAutobuilderPhase.Completed))
        assert resource.predictor.reference == ObjectReference("iris-product", "test-mab")
        resource.predictor.wait_until_ready()
        print(resource.predictor.predict(resource.dataset.test_prediction))
        resource.delete()


    def test_viz(self):
        resource = self.modela.ModelAutobuilder(namespace="iris-product", name="test-mab",
                                                data_file="datasets/iris.csv",
                                                target_column="variety",
                                                task_type=TaskType.MultiClassification)
        resource.submit_and_visualize(replace=True)



import unittest
from modela.data.models import *
from modela.data.DataSource import *
from google.protobuf.message import Message


class Test_Modela_configurations(unittest.TestCase):
    def test_datamodel(self):
        ty = DataLocation()
        print(ty.to_message())

    def test_parent_propagation(self):
        conf = CsvFileFormat()
        dc = DataSource()

        conf.set_parent(dc._object.spec.csvfile)
        conf.ColumnDelimiter = Delimiter.CRLF
        assert dc._object.spec.csvfile.columnDelimiter == Delimiter.CRLF.value
        dc._object.spec.csvfile.commentChars = "x"
        conf.CommentChars = "#"
        newconf = CsvFileFormat()
        newconf.copy_from(dc._object.spec.csvfile)
        assert newconf.ColumnDelimiter == Delimiter.CRLF
        assert newconf.CommentChars == "#"

        # Test propagation with subclass Message types
        conf = ExcelNotebookFormat()
        conf.set_parent(dc._object.spec.excelNotebook)
        conf.SheetName = "abc"
        conf.Data.ToColumn = 3
        assert dc._object.spec.excelNotebook.sheetName == "abc"
        assert dc._object.spec.excelNotebook.data.toColumn == 3
        conf.Data = ExcelSheetArea(ToColumn=5, EntireSheet=False)
        assert dc._object.spec.excelNotebook.data.toColumn == 5
        assert dc._object.spec.excelNotebook.data.entireSheet == False

        # Test propagation with list types
        assert len(dc._object.spec.schema.columns) == 0
        conf = Schema([Column(DataType.Text, Imputation=Imputation.ReplaceWithMean, SkewThreshold=4, Enum=["1", "2"])])
        conf.set_parent(dc._object.spec.schema)
        conf.Columns[0].Imputation = Imputation.AutoImputer
        assert dc._object.spec.schema.columns[0].imputation == Imputation.AutoImputer.value
        assert len(dc._object.spec.schema.columns) == 1
        conf.Columns.append(
            Column(DataType.Text, Imputation=Imputation.ReplaceWithMean, SkewThreshold=4, Enum=["1", "2"]))
        conf.Columns[0].Enum.append("test")
        conf.Columns[1].Enum[0] = "1337"
        assert dc._object.spec.schema.columns[0].enum[2] == "test"
        assert dc._object.spec.schema.columns[1].enum[0] == "1337"
        conf.Columns[0].Enum = ["a"]
        assert dc._object.spec.schema.columns[0].enum[0] == "a"
        conf.Columns[0].Enum.insert(0, "c")
        assert dc._object.spec.schema.columns[0].enum == ["c", "a"]
        newconf = Schema([])
        newconf.copy_from(dc._object.spec.schema)
        assert len(newconf.Columns) == 2

    def test_csv_config(self):
        conf = CsvFileFormat()
        conf.ColumnDelimiter = Delimiter.Colon
        dc = DataSource()
        dc._object.spec.csvfile.commentChars = "x"
        conf.apply_config(dc._object.spec.csvfile)
        newconf = CsvFileFormat()
        newconf.copy_from(dc._object.spec.csvfile)
        assert newconf.ColumnDelimiter == Delimiter.Colon
        assert newconf.CommentChars == "#"

    def test_excel_config(self):
        conf = ExcelNotebookFormat()
        conf.SheetName = "test"
        conf.Data.ToColumn = 3
        dc = DataSource()
        dc._object.spec.excelNotebook.data.fromColumn = 8
        conf.apply_config(dc._object.spec.excelNotebook)
        newconf = ExcelNotebookFormat()
        newconf.copy_from(dc._object.spec.excelNotebook)
        assert newconf.SheetName == "test"
        assert newconf.Data.ToColumn == 3
        assert newconf.Data.FromColumn == 1

    def test_schema_config(self):
        conf = Schema([Column(DataType.Text, Imputation=Imputation.ReplaceWithMean, SkewThreshold=4, Enum=["1", "2"]),
                       Column(DataType.Text, Imputation=Imputation.ReplaceWithMean, SkewThreshold=4, Enum=["1", "2"])])
        dc = DataSource()
        conf.apply_config(dc._object.spec.schema)
        newconf = Schema([])
        newconf.copy_from(dc._object.spec.schema)
        assert len(newconf.Columns) == 2


if __name__ == '__main__':
    unittest.main()



import unittest

from modela.ModelaException import *
from modela.data.DataProductVersion import DataProductVersion
from modela.data.common import DataType
from modela.data.models import DataProductVersionSpec, Column
from modela.server import Modela
from modela.training.common import Imputation


class Test_Modela_dataproductversion(unittest.TestCase):
    """Tests for `modela.data.DataProductVersion`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_0_create(self):
        dataproductversion = self.modela.DataProductVersion(namespace="iris-product", name="test")
        assert type(dataproductversion) == DataProductVersion
        dataproductversion.submit(replace=True)

    def test_1_list(self):
        assert len(self.modela.DataProductVersions.list("iris-product")) > 1

    def test_2_update(self):
        dataproductversion = self.modela.DataProductVersion(namespace="iris-product", name="test")
        dataproductversion.spec.Baseline = True
        dataproductversion.update()
        newdpv = self.modela.DataProductVersion(namespace="iris-product", name="test")
        assert newdpv._object.spec.baseline == True

    def test_3_get(self):
        dataproductversion = self.modela.DataProductVersion(namespace="iris-product", name="test")
        spec = dataproductversion.spec
        assert type(spec) == DataProductVersionSpec

    def test_4_delete(self):
        dataproductversion = self.modela.DataProductVersion(namespace="iris-product", name="test")
        dataproductversion.delete()
        self.assertRaises(ResourceNotFoundException, self.modela.DataProductVersions.get, "iris-product", "test")



import time
import unittest

import pandas

from modela.ModelaException import *
from modela.data.DataSource import DataSource
from modela.data.common import DataType
from modela.data.models import DataSourceSpec, Column
from modela.server import Modela
from modela.training.common import Imputation, TaskType


class Test_Modela_datasource(unittest.TestCase):
    """Tests for `modela.data.DataSource`"""
    resource: DataSource = None

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.clear_resource(cls)
        cls.modela.close()

    def request_resource(self, name, **kwargs) -> DataSource:
        self.clear_resource()
        Test_Modela_datasource.resource = self.modela.DataSource(namespace="iris-product",
                                                                 name=name,
                                                                 bucket="default-minio-bucket",
                                                                 **kwargs)

        return Test_Modela_datasource.resource

    def clear_resource(self):
        if Test_Modela_datasource.resource:
            Test_Modela_datasource.resource.delete()
            Test_Modela_datasource.resource = None

    def test_infer_api(self):
        with open('datasets/iris.csv') as f:
            data = f.read()

        loc = self.modela.FileService.upload_file("iris.csv", data, "default-tenant", "iris-product", "v0.0.1",
                                                  "default-minio-bucket", "datasources", "test")
        infer = self.modela.DataSources.infer("iris-product", loc)
        assert infer[0].Name == 'sepal.length'

    def test_0_create(self):
        resource = self.request_resource("test", task_type=TaskType.Regression)
        resource.submit(replace=True)
        time.sleep(0.5)
        resource = self.modela.DataSource(namespace="iris-product", name="test")
        assert resource.spec.Task == TaskType.Regression
        self.clear_resource()

    def test_0_infer_file(self):
        resource = self.request_resource("test", infer_file='datasets/iris.csv', target_column="variety")
        resource.submit(replace=True)
        resource = self.modela.DataSource(namespace="iris-product", name="test")
        assert resource.spec.Schema.Columns[0].Name == 'sepal.length'
        assert resource.spec.Schema.Columns[4].Target
        self.clear_resource()

    def test_0_infer_bytes(self):
        with open('datasets/iris.csv', 'rb') as f:
            data = f.read()

        resource = self.request_resource("test", infer_file='datasets/iris.csv', infer_bytes=data, target_column="variety")
        resource.submit(replace=True)
        resource = self.modela.DataSource(namespace="iris-product", name="test")
        assert resource.spec.Schema.Columns[0].Name == 'sepal.length'
        assert resource.spec.Schema.Columns[4].Target
        self.clear_resource()

    def test_1_create_infer_df(self):
        df = pandas.read_csv('datasets/iris.csv')
        resource = self.request_resource("test", infer_dataframe=df, target_column="variety")
        resource.submit(replace=True)
        resource = self.modela.DataSource(namespace="iris-product", name="test")
        assert resource.spec.Schema.Columns[0].Name == 'sepal.length'
        assert resource.spec.Schema.Columns[4].Target

    def test_2_list(self):
        assert len(self.modela.DataSources.list("iris-product")) >= 1

    def test_2_update(self):
        Test_Modela_datasource.resource.spec.Schema.Columns.append(
            Column("col", DataType.Text, Imputation=Imputation.ReplaceWithMean, SkewThreshold=4, Enum=["1", "2"]))
        Test_Modela_datasource.resource.update()
        ds = self.modela.DataSource(namespace="iris-product", name="test")
        assert ds.spec.Schema.Columns[5].Imputation == Imputation.ReplaceWithMean

    def test_3_get(self):
        datasource = self.modela.DataSource(namespace="iris-product", name="test")
        spec = datasource.spec
        assert datasource['sepal.length'] == Test_Modela_datasource.resource.spec.Schema.Columns[0]
        assert datasource.target_column == Test_Modela_datasource.resource.spec.Schema.Columns[4]
        self.clear_resource()


import unittest
from modela.server import Modela

class TestModela_account(unittest.TestCase):
    """Tests for `modela` package."""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_account_create(self):
        account = self.modela.Account(namespace="default-tenant", name="test")
        assert account != None
        account.submit(replace=True, password="test")

    def test_account_update(self):
        pass

    def test_account_get(self):
        account = self.modela.Account(namespace="default-tenant", name="admin")

    def test_account_delete(self):
        account = self.modela.Account(namespace="default-tenant", name="test")
        account.delete()

    def test_account_list(self):
        print(self.modela.Accounts.list("default-tenant"))



        



import time
import unittest

from modela import *
from modela.ModelaException import *
from modela.common import PriorityLevel
from modela.data.DataProduct import DataProduct
from modela.data.common import DataType
from modela.data.models import DataProductSpec
from modela.server import Modela
from modela.training.common import Imputation, TaskType


class Test_Modela_dataproduct(unittest.TestCase):
    """Tests for `modela.data.DataProduct`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_0_create(self):
        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test",
                                              serving_site="serving-site",
                                              lab="lab",
                                              public=True,
                                              task_type=TaskType.Regression,
                                              default_training_workload=Workload("general-small"),
                                              default_serving_workload=Workload("general-small"),
                                              default_bucket="test",
                                              notification_settings=NotificationSettings(NotifierName="test"))
        dataproduct.submit(replace=True)
        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test")
        assert dataproduct.spec.ServingSiteName == "serving-site"
        assert dataproduct.spec.LabName == "lab"
        assert dataproduct.spec.Public
        assert dataproduct.spec.TrainingResources == Workload("general-small")
        assert dataproduct.spec.ServingResources == Workload("general-small")
        assert dataproduct.spec.DataLocation.BucketName == "test"
        assert dataproduct.spec.Notification == NotificationSettings(NotifierName="test")
        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test",
                                              serving_site=self.modela.ServingSite("default-tenant",
                                                                                   "default-serving-site"),
                                              lab=self.modela.Lab("default-tenant", "default-lab"))
        dataproduct.update()
        dataproduct.sync()
        assert dataproduct.spec.ServingSiteName == "default-serving-site"
        assert dataproduct.spec.LabName == "default-lab"
        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test",
                                              permissions=Permissions.create({
                                                  self.modela.Account("default-tenant", "administrator"):
                                                      self.modela.UserRoleClass("default-tenant", "administrator")
                                              }))
        dataproduct.update()
        dataproduct.sync()
        assert dataproduct.spec.Permissions == \
               Permissions(Stakeholders=[Stakeholder(Account='administrator', Roles=[
                   ObjectReference(Namespace='default-tenant', Name='administrator')])])

        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test",
                                              permissions=Permissions.create({
                                                  self.modela.Account("default-tenant", "administrator"): [
                                                      'administrator', 'business']
                                              }))
        dataproduct.update()
        dataproduct.sync()
        assert dataproduct.spec.Permissions == \
               Permissions(Stakeholders=[Stakeholder(Account='administrator', Roles=[
                   ObjectReference(Namespace='default-tenant', Name='administrator'),
                   ObjectReference(Namespace='default-tenant', Name='business')])])

    def test_1_list(self):
        assert len(self.modela.DataProducts.list("default-tenant")) == 2

    def test_2_update(self):
        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test")
        assert dataproduct.spec.Priority == PriorityLevel.Medium
        dataproduct.spec.Priority = PriorityLevel.High
        dataproduct.update()
        newdp = self.modela.DataProduct(namespace="default-tenant", name="test")
        assert newdp._object.spec.priority == "high"

    def test_3_get(self):
        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test")
        assert type(dataproduct.spec) == DataProductSpec

    def test_4_delete(self):
        dataproduct = self.modela.DataProduct(namespace="default-tenant", name="test")
        dataproduct.delete()
        self.assertRaises(ResourceNotFoundException, self.modela.DataProducts.get, "default-tenant", "test")



import unittest
from time import sleep

from tqdm import *

from modela.ModelaException import *
from modela.training.Model import Model
from modela.server import Modela
from modela.training.models import ModelSpec
import pprint

class Test_Modela_model(unittest.TestCase):
    """Tests for `modela.training.Model`"""

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def test_upload(self):
        with open('datasets/iris.csv', 'r') as f:
            data = f.read()

        self.modela.FileService.upload_file("test", data, "default-tenant", "iris-product", "v0.0.1",
                                            "default-minio-bucket", "dataset", "test")



import time
import unittest

from modela.ModelaException import *
from modela.data.Dataset import Dataset
from modela.server import Modela
from modela import *
from modela.util import convert_size

from google.protobuf.json_format import MessageToJson


class Test_Modela_dataset(unittest.TestCase):
    """Tests for `modela.data.Dataset`"""
    resource: Dataset = None

    @classmethod
    def setUpClass(cls):
        cls.modela = Modela(port_forward=True)

    @classmethod
    def tearDownClass(cls):
        cls.modela.close()

    def request_resource(self, name, **kwargs) -> Dataset:
        self.clear_resource()
        Test_Modela_dataset.resource = self.modela.Dataset(namespace="iris-product",
                                                           name=name,
                                                           data_file='datasets/heart.csv',
                                                           bucket="default-minio-bucket",
                                                           task_type=TaskType.BinaryClassification,
                                                           **kwargs)
        return Test_Modela_dataset.resource

    def clear_resource(self):
        if Test_Modela_dataset.resource:
            Test_Modela_dataset.resource.delete()
            Test_Modela_dataset.resource = None

    def test_0_create_from_ds(self):
        datasource = self.modela.DataSource(namespace="iris-product", name="test-create-ds",
                                            infer_file='datasets/heart.csv',
                                            target_column="target",
                                            task_type=TaskType.BinaryClassification)
        datasource.submit(replace=True)
        dataset = self.request_resource("test-ds-0", datasource=datasource)
        dataset.submit(replace=True)
        assert len(self.modela.Datasets.list("iris-product")) >= 1
        assert dataset.datasource.reference == datasource.reference
        self.clear_resource()
        datasource.delete()
        time.sleep(0.5)
        self.assertRaises(ResourceNotFoundException, self.modela.Datasets.get, "iris-product", "test-ds-0")

    def test_0_create_gen_ds(self):
        dataset = self.request_resource("test-ds-gen", gen_datasource=True, target_column="target")
        dataset.submit(replace=True)
        assert len(self.modela.Datasets.list("iris-product")) >= 1
        assert len(self.modela.DataSources.list("iris-product")) >= 1
        ds = self.modela.DataSources.get("iris-product", "test-ds-gen-source")
        assert len(ds.schema.Columns) == 14
        assert dataset.datasource.reference == ds.reference
        assert dataset.datasource.spec.Task == TaskType.BinaryClassification
        self.clear_resource()

    def test_1_viz(self):
        dataset = self.request_resource("test-ds-gen", gen_datasource=True, target_column="target")
        dataset.submit_and_visualize(replace=True)
        assert dataset.phase == DatasetPhase.Ready

    def test_2_list(self):
        assert len(self.modela.Datasets.list("iris-product")) >= 1

    def test_2_print(self):
        print(Test_Modela_dataset.resource)

    def test_2_payload(self):
        print(Test_Modela_dataset.resource.test_prediction)

    def test_2_profile(self):
        print(Test_Modela_dataset.resource.profile)

    def test_2_report(self):
        print(Test_Modela_dataset.resource.report)

    def test_3_update(self):
        Test_Modela_dataset.resource.set_label("test2", "e")
        Test_Modela_dataset.resource.update()
        newDs = self.modela.Dataset(namespace="iris-product", name="test-ds-gen")
        assert newDs.has_label("test2")


""" These tests should be run by an end-user. """


def test_viz():
    modela = Modela(port_forward=True)
    datasource = modela.DataSource(namespace="iris-product", name="iris")
    dataset = modela.Dataset(namespace="iris-product", name="test-ds-5", data_file='tests/datasets/iris.csv',
                             datasource=datasource, task_type=TaskType.MultiClassification)

    dataset.submit_and_visualize(replace=True)
    modela.close()
